package App::YouTubeUtils;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-04-01'; # DATE
our $DIST = 'App-YouTubeUtils'; # DIST
our $VERSION = '0.004'; # VERSION

1;
# ABSTRACT: Command-line utilities related to YouTube

__END__

=pod

=encoding UTF-8

=head1 NAME

App::YouTubeUtils - Command-line utilities related to YouTube

=head1 VERSION

This document describes version 0.004 of App::YouTubeUtils (from Perl distribution App-YouTubeUtils), released on 2020-04-01.

=head1 DESCRIPTION

This distribution provides the following command-line utilities related to
YouTube:

=over

=item * L<extract-youtube-video-ids>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-YouTubeUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-YouTubeUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-YouTubeUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<youtube-dl-if-not-yet> from L<App::YoutubeDlIfNotYet>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
